@@ -30,12 +30,14 @@ use EmailReminder::Utils;
 
 require Exporter;
 our @ISA = ("Exporter");
-our @EXPORT = qw(is_occurring);
+our @EXPORT = qw(is_occurring get_reminder_email get_reminder_name);
 
 # XML tags, attributes and values
 
 my $REMINDER_TAG = 'reminder';
 my $REMINDERS_TAG = 'reminders';
+my $REMINDER_NAME_TAG = 'reminder-name';
+my $REMINDER_EMAIL_TAG = 'reminder-email';
 
 my $TYPE_ATTR = 'type';
 
@@ -74,6 +76,10 @@ sub new
         push(@{$this->{DATA}}, undef);
     }
 
+    # Where to send this reminder email
+    $this->{REMINDER_NAME} = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $REMINDER_NAME_TAG);
+    $this->{REMINDER_EMAIL} = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $REMINDER_EMAIL_TAG);
+
     # Process reminders
     my $reminders = $this->{XML_NODE}->getElementsByTagName($REMINDERS_TAG)->item(0);
     if (defined($reminders)) {
@@ -212,7 +218,8 @@ $body
 Have a good day!
 
 --
-Sent by Email-Reminder
+Sent by Email-Reminder $EmailReminder::Utils::VERSION
+http://people.debian.org/~francois/email-reminder/
 MESSAGEEND
 
     return $message;
@@ -230,4 +237,16 @@ sub get_id
     return $this->{ID};
 }
 
+sub get_reminder_name()
+{
+    my $this = shift;
+    return $this->{REMINDER_NAME};
+}
+
+sub get_reminder_email()
+{
+    my $this = shift;
+    return $this->{REMINDER_EMAIL};
+}
+
 1;
